@@ -1,29 +1,9 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2007-09-03
- * @brief  Exiv2 library interface for KDE
- *
- * @author Copyright (C) 2006-2015 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
- *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2006-2015 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2006-2012 Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kexiv2_p.h"
 
@@ -62,22 +42,20 @@ extern "C"
 namespace KExiv2Iface
 {
 
-KExiv2::Private::Private()
-    : data(new KExiv2Data::Private)
+KExiv2Private::KExiv2Private()
+    : data(new KExiv2DataPrivate)
 {
     writeRawFiles         = false;
     updateFileTimeStamp   = false;
     useXMPSidecar4Reading = false;
-    metadataWritingMode   = WRITETOIMAGEONLY;
+    metadataWritingMode   = KExiv2::WRITETOIMAGEONLY;
     loadedFromSidecar     = false;
-    Exiv2::LogMsg::setHandler(KExiv2::Private::printExiv2MessageHandler);
+    Exiv2::LogMsg::setHandler(KExiv2Private::printExiv2MessageHandler);
 }
 
-KExiv2::Private::~Private()
-{
-}
+KExiv2Private::~KExiv2Private() = default;
 
-void KExiv2::Private::copyPrivateData(const Private* const other)
+void KExiv2Private::copyPrivateData(const KExiv2Private* const other)
 {
     data                  = other->data;
     filePath              = other->filePath;
@@ -87,7 +65,7 @@ void KExiv2::Private::copyPrivateData(const Private* const other)
     metadataWritingMode   = other->metadataWritingMode;
 }
 
-bool KExiv2::Private::saveToXMPSidecar(const QFileInfo& finfo) const
+bool KExiv2Private::saveToXMPSidecar(const QFileInfo& finfo) const
 {
     QString filePath = KExiv2::sidecarFilePathForFile(finfo.filePath());
 
@@ -114,7 +92,7 @@ bool KExiv2::Private::saveToXMPSidecar(const QFileInfo& finfo) const
     }
 }
 
-bool KExiv2::Private::saveToFile(const QFileInfo& finfo) const
+bool KExiv2Private::saveToFile(const QFileInfo& finfo) const
 {
     if (!finfo.isWritable())
     {
@@ -124,19 +102,15 @@ bool KExiv2::Private::saveToFile(const QFileInfo& finfo) const
 
     QStringList rawTiffBasedSupported, rawTiffBasedNotSupported;
 
-    // Raw files supported by Exiv2 0.21
+    // Raw files supported by Exiv2 0.23
     rawTiffBasedSupported << QString::fromLatin1("dng")
                           << QString::fromLatin1("nef")
                           << QString::fromLatin1("pef")
                           << QString::fromLatin1("orf")
-                          << QString::fromLatin1("srw");
+                          << QString::fromLatin1("srw")
+                          << QString::fromLatin1("cr2");
 
-    if (Exiv2::testVersion(0,23,0))
-    {
-        rawTiffBasedSupported << QString::fromLatin1("cr2");
-    }
-
-    // Raw files not supported by Exiv2 0.21
+    // Raw files not supported by Exiv2 0.23
     rawTiffBasedNotSupported << QString::fromLatin1("3fr")
                              << QString::fromLatin1("arw")
                              << QString::fromLatin1("dcr")
@@ -149,11 +123,6 @@ bool KExiv2::Private::saveToFile(const QFileInfo& finfo) const
                              << QString::fromLatin1("srf")
                              << QString::fromLatin1("rw2");
 
-    if (!Exiv2::testVersion(0,23,0))
-    {
-        rawTiffBasedNotSupported << QString::fromLatin1("cr2");
-    }
-
     QString ext = finfo.suffix().toLower();
 
     if (!writeRawFiles && (rawTiffBasedSupported.contains(ext) || rawTiffBasedNotSupported.contains(ext)) )
@@ -202,7 +171,7 @@ bool KExiv2::Private::saveToFile(const QFileInfo& finfo) const
     }
 }
 
-bool KExiv2::Private::saveOperations(const QFileInfo& finfo, Exiv2::Image::AutoPtr image) const
+bool KExiv2Private::saveOperations(const QFileInfo& finfo, Exiv2::Image::AutoPtr image) const
 {
     try
     {
@@ -362,7 +331,7 @@ bool KExiv2::Private::saveOperations(const QFileInfo& finfo, Exiv2::Image::AutoP
     return false;
 }
 
-void KExiv2Data::Private::clear()
+void KExiv2DataPrivate::clear()
 {
     imageComments.clear();
     exifMetadata.clear();
@@ -372,19 +341,19 @@ void KExiv2Data::Private::clear()
 #endif
 }
 
-void KExiv2::Private::printExiv2ExceptionError(const QString& msg, Exiv2::Error& e)
+void KExiv2Private::printExiv2ExceptionError(const QString& msg, Exiv2::Error& e)
 {
     std::string s(e.what());
     qCCritical(LIBKEXIV2_LOG) << msg.toLatin1().constData() << " (Error #"
                               << e.code() << ": " << s.c_str();
 }
 
-void KExiv2::Private::printExiv2MessageHandler(int lvl, const char* msg)
+void KExiv2Private::printExiv2MessageHandler(int lvl, const char* msg)
 {
     qCDebug(LIBKEXIV2_LOG) << "Exiv2 (" << lvl << ") : " << msg;
 }
 
-QString KExiv2::Private::convertCommentValue(const Exiv2::Exifdatum& exifDatum) const
+QString KExiv2Private::convertCommentValue(const Exiv2::Exifdatum& exifDatum) const
 {
     try
     {
@@ -439,7 +408,7 @@ QString KExiv2::Private::convertCommentValue(const Exiv2::Exifdatum& exifDatum)
     return QString();
 }
 
-QString KExiv2::Private::detectEncodingAndDecode(const std::string& value) const
+QString KExiv2Private::detectEncodingAndDecode(const std::string& value) const
 {
     // For charset autodetection, we could use sophisticated code
     // (Mozilla chardet, KHTML's autodetection, QTextCodec::codecForContent),
@@ -465,7 +434,7 @@ QString KExiv2::Private::detectEncodingAndDecode(const std::string& value) const
     return QString::fromLocal8Bit(value.c_str());
 }
 
-bool KExiv2::Private::isUtf8(const char* const buffer) const
+bool KExiv2Private::isUtf8(const char* const buffer) const
 {
     int i, n;
     register unsigned char c;
@@ -584,7 +553,7 @@ done:
 #undef I
 #undef X
 
-int KExiv2::Private::getXMPTagsListFromPrefix(const QString& pf, KExiv2::TagsMap& tagsMap) const
+int KExiv2Private::getXMPTagsListFromPrefix(const QString& pf, KExiv2::TagsMap& tagsMap) const
 {
     int i = 0;
 
@@ -630,7 +599,7 @@ int KExiv2::Private::getXMPTagsListFromPrefix(const QString& pf, KExiv2::TagsMap
 }
 
 #ifdef _XMP_SUPPORT_
-void KExiv2::Private::loadSidecarData(Exiv2::Image::AutoPtr xmpsidecar)
+void KExiv2Private::loadSidecarData(Exiv2::Image::AutoPtr xmpsidecar)
 {
     // Having a sidecar is a special situation.
     // The sidecar data often "dominates", see in particular bug 309058 for important aspects:
